@@ -1,35 +1,11 @@
-# Copyright (C) 2009-2014 by Barry A. Warsaw
-#
-# This file is part of flufl.i18n
-#
-# flufl.i18n is free software: you can redistribute it and/or modify it under
-# the terms of the GNU Lesser General Public License as published by the Free
-# Software Foundation, version 3 of the License.
-#
-# flufl.i18n is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
-# for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with flufl.i18n.  If not, see <http://www.gnu.org/licenses/>.
-
 """Catalog search strategies."""
 
-from __future__ import absolute_import, print_function, unicode_literals
-
-__metaclass__ = type
-__all__ = [
-    'PackageStrategy',
-    'SimpleStrategy',
-    ]
-
-
 import os
 import gettext
 
+from public import public
+
 
-
 class _BaseStrategy:
     """Common code for strategies."""
 
@@ -61,6 +37,7 @@ class _BaseStrategy:
             return gettext.NullTranslations()
 
 
+@public
 class PackageStrategy(_BaseStrategy):
     """A strategy that finds catalogs based on package paths."""
 
@@ -74,11 +51,11 @@ class PackageStrategy(_BaseStrategy):
             containing `gettext` messages.
         :type package_name: module
         """
-        super(PackageStrategy, self).__init__(name)
+        super().__init__(name)
         self._messages_dir = os.path.dirname(package.__file__)
 
 
-
+@public
 class SimpleStrategy(_BaseStrategy):
     """A simpler strategy for getting translations."""
 
@@ -92,5 +69,5 @@ class SimpleStrategy(_BaseStrategy):
             containing `gettext` messages.
         :type package_name: module
         """
-        super(SimpleStrategy, self).__init__(name)
+        super().__init__(name)
         self._messages_dir = os.environ.get('LOCPATH')
